%% <PRE>
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Copyright (c) Maplesoft, a division of Waterloo Maple Inc. 2003 
% All rights reserved. Maple is a trademark of Waterloo Maple Inc.
%
% Permission is granted to these macro definitions without charge. They may
% be redistributed providing that it is distributed as is
% and without charge.  You may modify these macros for your own use,
% and redistribute them without charge, subject to the following conditions.
%
% 1. The file name used for any modified version of this file is 
%    different from mapleenv.def. 
%
% 2. You acknowledge this copyright notice and this file as the source.
%
% 3. The new file is redistributed under the same terms and conditions 
%    as indicated here, including a version of this notice modified to
%    refer to the new file and/or package name.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mapleenv.def
%
% These macro definitions are included by mapleenv.sty
%
% They control most of the spacing surrounding the standard 
% Maple environments.  This file provides the default values, but
% they are all resettable in the preamble of your document. 
% 
% \AboveMapleSkip	- space above an environment
% \BelowMapleSkip	- space below an environment
% \AboveMaplePlot	- space above a Maple Plot 
% \BelowMaplePlot	- space below a Maple Plot
% \MaplePlotHeight	- vertical space reserved for a plot
% \MaplePlotWidth	- width reserved for a plot
% \MaplePlotAngle	- angle of rotatation
% \LeftMapleSkip 	- the amount of left indentation
% \MapleFont 		- The Maple font 
% \MapleSize 		- The size of the Maple font in mapleinput and 
%                          maplettyout
% \MapleLatexSize	- The size of the Maple fonts in maplelatex
% \MapleFirstLine	- controls ingoring first line feed
% \MaplePrompttrue 	- controls insertion of prompt char
% \MaplePromptString	- defines the prompt string
% \MaplePromptSecondary	- defines the secondary prompt string
% \MapleSkip		- amount of glue before and after
%			displayed text
% \MapleTab		- number of spaces per tab (8)
%
% Spacing, dimensions, etc.  
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newskip\AboveMapleSkip		% space above the maple environments.
\newskip\BelowMapleSkip		% space below the maple environments.
\newdimen\LeftMapleSkip 	% indentation for the maple commands.
\newskip\AboveMaplePlot		% spacing above and below maple plots.
\newskip\BelowMaplePlot
\newdimen\MaplePlotHeight 	% size of the maple plot.
\newdimen\MaplePlotWidth 
\newdimen\MaplePlotHeight@Fudge	% dimensions of the Maple plot - needed
\newdimen\MaplePlotWidth@Fudge	% to compensate for extra space around plot
\newdimen\MapleSepLineWidth 
\newif\ifMapleFirstLine		% flag to control printing of first CR
\newif\ifMaplePrompt		% flag to control prompting
\newcount\MapleTab	
\newtoks\MaplePromptString 
\newtoks\MaplePromptSecondary 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Set the Default Values  
%
\AboveMapleSkip  = 0.5ex plus 3 pt minus 0 pt
\BelowMapleSkip  = 0.5\AboveMapleSkip
\LeftMapleSkip   = 1.5em		  
\AboveMaplePlot  = 2\AboveMapleSkip
\BelowMaplePlot  = \AboveMapleSkip
\MaplePlotWidth  = 0.900\textwidth
\MaplePlotHeight = 0.651\textwidth
%%% \edef\MaplePlotAngle{270}	% assume Maple plots are in landscape mode
\edef\MaplePlotAngle{0}		% assume Maple plots are in portrait mode
%
% separator line parameters (obsolete)
%
\newdimen\MapleSepLineHeight \MapleSepLineHeight = 0.01in
\let\MapleSepLineWidth\linewidth  % use \let for automatic scaling
\MapleSepLineHeight = 1pt
%
% Font characteristics and other controls 
% for inside Maple's special verbatim environments.
%
\def\MapleSize{\small}
\def\MapleFont{\tt}
\def\@MapleFont{\MapleFont\MapleSize\@noligs}  % used in mapletty envs.
\def\MapleLatexSize{\normalsize} % change this to change maplelatex size
\MapleFirstLinefalse  % Ignore first \cr after \begin{mapleinput}  
\MaplePrompttrue      % Include the prompt string for each input line.
\MapleTab = 8
\MaplePromptString = {\raise 1pt \hbox{$\scriptstyle>$\space}}
\MaplePromptSecondary = \MaplePromptString % prompts  on every line
% \MaplePromptSecondary = {\space\space} % no prompts after first line
%
\newif\ifMapleTableCell%  % used to change vertical offset of a
			  % mapleinline inside table
\endinput
%%% </PRE>
